rhythmmakertools.BurnishSpecifier
=================================

.. abjad-lineage:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier

.. autoclass:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.burnish_divisions
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.burnish_output
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.left_lengths
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.lefts
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.middles
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.reverse
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.right_lengths
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.rights
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.rotate
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__eq__
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__format__
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__hash__
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__ne__
      ~abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__repr__

Bases
-----

- :py:class:`abctools.AbjadValueObject <abjad.tools.abctools.AbjadValueObject.AbjadValueObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.burnish_divisions
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.burnish_output
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.left_lengths
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.lefts
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.middles
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.right_lengths
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.rights
   :noindex:

Methods
-------

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.reverse
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.rotate
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__eq__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__format__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__hash__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__ne__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.BurnishSpecifier.BurnishSpecifier.__repr__
   :noindex:
